%global python3_version 3.9

Name:           syslog-ng
Version:        4.8.1
Release:        1
Summary:        Enhanced system logging daemon
License:        GPL-2.0-only
Group:          System/Daemons
URL:            https://syslog-ng.org/
Source0:        https://github.com/syslog-ng/syslog-ng/releases/download/%{name}-%{version}/%{name}-%{version}.tar.gz
Patch0:         syslog-ng-4.8.1-aix-build.patch
Patch1:         syslog-ng-4.8.1-asprintf-aix.patch
Patch2:         syslog-ng-4.8.1-func_data-aix.patch
Patch3:         syslog-ng-4.8.1-getservbyport_r-aix.patch
Patch4:         syslog-ng-4.8.1-ip_tos-aix.patch
Patch5:         syslog-ng-4.8.1-tls-support.patch    
Patch6:         syslog-ng-4.8.1-remove-libdir-aix.patch
patch7:         syslog-ng-4.8.1-ctl-aix.patch

BuildRequires:  pcre2-devel >= 10.40
BuildRequires:  json-c-devel >= 0.17
BuildRequires:  gettext-devel >= 0.21
BuildRequires:  glib2-devel >= 2.81.0
BuildRequires:  curl-devel >= 8.9.1
BuildRequires:  zlib-devel >= 1.2.13
BuildRequires:  libdbi-devel >= 0.9.0
BuildRequires:  ivykis-devel >= 0.43.2

Requires:  pcre2 >= 10.40
Requires:  json-c >= 0.17
Requires:  gettext >= 0.21
Requires:  glib2 >= 2.81.0
Requires:  curl >= 8.9.1
Requires:  zlib >= 1.2.13
Requires:  libgcc >= 10.3.0
Requires:  libstdc++ >= 10.3.0
Requires:  libdbi >= 0.9.0
Requires:  ivykis >= 0.43.2

%description
syslog-ng is an enhanced log daemon, supporting a wide range of input and
output methods: syslog, unstructured text, message queues, databases (SQL
and NoSQL alike) and more.

Key features:

 * receive and send RFC3164 and RFC5424 style syslog messages
 * work with any kind of unstructured data
 * receive and send JSON formatted messages
 * classify and structure logs with builtin parsers (csv-parser(),
   db-parser(), ...)
 * normalize, crunch and process logs as they flow through the system
 * hand on messages for further processing using message queues (like
   AMQP), files or databases (like PostgreSQL or MongoDB).

%package devel
Summary: Development files for %{name}
Requires: %{name} = %{version}-%{release}

Requires: glib2-devel >= 2.81.0

%description devel
The %{name}-devel package contains header files and pkgconfig files for
developing applications that use %{name}.

%package python
Summary: Python support for %{name}
Requires: %{name} = %{version}-%{release}
Requires: python%{python3_version} >= %{python3_version}.20

%description python
This package provides python support for syslog-ng.
To use the python modules, you may need additional third-party
python modules. Please see the list of such modules at 
/opt/freeware/lib/syslog-ng/python/requirements.txt. Install
the modules which are available in AIX Toolbox as rpms. For 
other modules, use pip to install it in a different directory  
(--root) and set the PYTHONPATH to use them.


%prep
%setup -q -n syslog-ng-%{version}
./autogen.sh
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1

%build
export CC="gcc -pthread -maix64 -O2 -D_ALL_SOURCE -D_LINUX_SOURCE_COMPAT"
export CXX="g++ -pthread -maix64 -O2 -D_ALL_SOURCE -D_LINUX_SOURCE_COMPAT"
export LDFLAGS="-Wl,-blibpath:/opt/freeware/lib/pthread:/opt/freeware/lib64:/opt/freeware/lib:/usr/lib"
export OBJECT_MODE=64
export PKG_CONFIG_PATH=/opt/freeware/lib64/pkgconfig:/opt/freeware/lib/pkgconfig:/usr/lib/pkgconfig
export PYTHON=python%{python3_version}

./configure --enable-cloud-auth=no --prefix=%{_prefix} --sysconfdir=%{_sysconfdir}/%{name} --with-python=%{python3_version} --with-ivykis=system --mandir=%{_mandir}
gmake V=1 -j8

%install
export OBJECT_MODE=64
gmake install DESTDIR=${RPM_BUILD_ROOT}

rm -f ${RPM_BUILD_ROOT}%{_libdir}/*.la
rm -f ${RPM_BUILD_ROOT}%{_libdir}/syslog-ng/*.la
rm -f ${RPM_BUILD_ROOT}%{_libdir}/syslog-ng/loggen/*.la

%files
%doc AUTHORS COPYING NEWS.md
%doc contrib/relogger.pl contrib/syslog2ng contrib/syslog-ng.conf.doc
%{_bindir}/*
%{_sbindir}/*
%{_libdir}/*.a
%{_libdir}/%{name}
%exclude %{_libdir}/%{name}/libmod-python.a
%exclude %{_libdir}/%{name}/python/
%dir %{_sysconfdir}/syslog-ng
%config(noreplace) %{_sysconfdir}/syslog-ng/syslog-ng.conf
%{_datadir}/syslog-ng
%{_mandir}/man?/*

%files devel
%{_includedir}/*
%{_libdir}/pkgconfig/*

%files python
%{_libdir}/%{name}/libmod-python.a
%dir %{_sysconfdir}/%{name}/python
%{_sysconfdir}/%{name}/python/README.md
%{_libdir}/%{name}/python/syslogng-1.0-py%{python3_version}.egg-info
%{_libdir}/%{name}/python/syslogng/*
%{_libdir}/%{name}/python/requirements.txt


%changelog
* Wed Jun 11 2025 Ayappan Perumal <ayappap2@in.ibm.com> - 4.8.1-1
- First port to AIX Toolbox
